import db from "@/utils/db";
import { NextRequest, NextResponse } from "next/server";

export async function GET(
	req: NextRequest,
	{ params }: { params: { id: string } }
) {
	const user = await db.user.findUnique({
		where: { id: params.id },
	});
	if (!user) {
		return NextResponse.json({ error: "User not found" }, { status: 404 });
	} else {
		return NextResponse.json(user, { status: 200 });
	}
}

export async function PUT(
	req: NextRequest,
	{ params }: { params: { id: string } }
) {
	const { name, email, role, status, phone } = await req.json();
	const user = await db.user.findUnique({
		where: { id: params.id },
	});
	if (!user) {
		return NextResponse.json({ error: "User not found" }, { status: 404 });
	} else {
		try {
			const updatedUser = await db.user.update({
				where: { id: params.id },
				data: {
					name,
					email,
					role,
					status,
					phone,
				},
			});
			return NextResponse.json(
				{ message: "user updated successfuly", updatedUser },
				{ status: 200 }
			);
		} catch (error) {
			return NextResponse.json(
				{ error: "Failed to update user" },
				{ status: 500 }
			);
		}
	}
}

export async function DELETE(
	req: NextRequest,
	{ params }: { params: { id: string } }
) {
	const user = await db.user.findUnique({
		where: { id: params.id },
	});
	if (!user) {
		return NextResponse.json({ error: "User not found" }, { status: 404 });
	} else {
		try {
			await db.user.delete({
				where: { id: params.id },
			});
			return NextResponse.json(
				{ message: "user deleted successfuly", user },
				{ status: 200 }
			);
		} catch (error) {
			return NextResponse.json(
				{ error: "Failed to delete user" },
				{ status: 500 }
			);
		}
	}
}
